@@ -4,8 +4,8 @@ Asynchronous low-level communication with BitTorrent clients
 
 __project_name__ = 'aiobtclientrpc'
 __description__ = 'Asynchronous low-level communication with BitTorrent clients'
-__homepage__ = 'https://codeberg.org/ormaybe/aiobtclientrpc'
-__version__ = '3.0.0'
+__homepage__ = 'https://codeberg.org/plotski/aiobtclientrpc'
+__version__ = '3.0.2'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
