@@ -546,7 +546,11 @@ def test_create_http_client(username, password, proxy_url, mocker):
     argnames='raised_exception, exp_exception',
     argvalues=(
         (httpx.HTTPError('Fail'), _errors.ConnectionError('Fail')),
+        (httpx.HTTPError('[Errno 123] Ugly fail'), _errors.ConnectionError('Ugly fail')),
+        (httpx.HTTPError('[Errno -123] Ugly negative fail'), _errors.ConnectionError('Ugly negative fail')),
         (httpx_socks.ProxyError('Fail'), _errors.ConnectionError('Fail')),
+        (httpx_socks.ProxyError('[Errno 456] Ugly fail'), _errors.ConnectionError('Ugly fail')),
+        (httpx_socks.ProxyError('[Errno -456] Ugly negative fail'), _errors.ConnectionError('Ugly negative fail')),
         (ConnectionAbortedError(), _errors.ConnectionError('Connection aborted')),
         (ConnectionRefusedError(), _errors.ConnectionError('Connection refused')),
         (ConnectionResetError(), _errors.ConnectionError('Connection reset')),
